@@ -19,10 +19,10 @@ use strict;
 
       if(/<para><ulink url=\"&url_examples_base;([\/\w]+)\">Source Code<\/ulink><\/para>\s*(?:<!--\s*Insert\s+(.*?)-->)?/)
       {
-        #Modify the line to add the branch, so people see the correct version.
-        #This is particularly important during major API changes every few years,
-        #when the API might no longer even exist in the new version.
-        print "<para><ulink url=\"&url_examples_base;${1}?h=&url_examples_branchsuffix;\">Source Code<\/ulink><\/para>\n";
+        # Modify the line to remove the trailing comment, if any.
+        # url_examples_base is assumed to be a GitLab URL. The branch is then
+        # included in url_examples_base. No need to add it here.
+        print "<para><ulink url=\"&url_examples_base;$1\">Source Code</ulink></para>\n";
 
         #List all the source files in that directory:
         my $directory = $examples_base . $1;
@@ -74,7 +74,10 @@ sub process_source_file($$$)
   print "</para>\n";
   print "<programlisting>\n";
 
-  open(SOURCE_FILE, "$directory/$source_file");
+  if (!open(SOURCE_FILE, "$directory/$source_file"))
+  {
+    print STDERR "Can't open $directory/$source_file\n";
+  }
 
   while(<SOURCE_FILE>)
   {
