@@ -19,8 +19,8 @@
 ExampleWindow::ExampleWindow()
 : m_gallery_button("Gallery"),
   m_effects_button("Effects"),
-  m_box(Gtk::ORIENTATION_VERTICAL),
-  m_photo_box(Gtk::ORIENTATION_HORIZONTAL)
+  m_box(Gtk::Orientation::VERTICAL),
+  m_photo_box(Gtk::Orientation::HORIZONTAL)
 {
   // Window properties
   set_title("ActionBar Example");
@@ -31,15 +31,16 @@ ExampleWindow::ExampleWindow()
   settings->property_gtk_application_prefer_dark_theme().set_value(true);
 
   // Face
-  m_face_image.set_from_icon_name("face-cool", Gtk::ICON_SIZE_DIALOG);
+  m_face_image.set_from_icon_name("face-cool");
+  m_face_image.set_icon_size(Gtk::IconSize::LARGE);
 
   // Center widget layout
-  m_prev_button.set_image_from_icon_name("go-previous-symbolic", Gtk::ICON_SIZE_BUTTON, true);
-  m_next_button.set_image_from_icon_name("go-next-symbolic", Gtk::ICON_SIZE_BUTTON, true);
-  m_photo_button.set_image_from_icon_name("media-record-symbolic", Gtk::ICON_SIZE_BUTTON, true);
-  m_photo_box.pack_start(m_prev_button, Gtk::PACK_SHRINK);
-  m_photo_box.pack_start(m_photo_button, Gtk::PACK_SHRINK);
-  m_photo_box.pack_start(m_next_button, Gtk::PACK_SHRINK);
+  m_prev_button.set_image_from_icon_name("go-previous-symbolic", Gtk::IconSize::INHERIT, true);
+  m_next_button.set_image_from_icon_name("go-next-symbolic", Gtk::IconSize::INHERIT, true);
+  m_photo_button.set_image_from_icon_name("media-record-symbolic", Gtk::IconSize::INHERIT, true);
+  m_photo_box.add(m_prev_button);
+  m_photo_box.add(m_photo_button);
+  m_photo_box.add(m_next_button);
   auto style_context = m_photo_box.get_style_context();
   style_context->add_class("raised");
   style_context->add_class("linked");
@@ -51,11 +52,10 @@ ExampleWindow::ExampleWindow()
 
   // Layout
   m_box.set_homogeneous(false);
-  m_box.pack_start(m_face_image, Gtk::PACK_EXPAND_WIDGET);
-  m_box.pack_end(m_action_bar, Gtk::PACK_SHRINK);
+  m_face_image.set_expand();
+  m_box.add(m_face_image);
+  m_box.add(m_action_bar);
   add(m_box);
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
