@@ -28,19 +28,19 @@ ExampleAppWindow::ExampleAppWindow(BaseObjectType* cobject,
   m_searchentry(nullptr),
   m_prop_binding()
 {
-  m_refBuilder->get_widget("stack", m_stack);
+  m_stack = m_refBuilder->get_widget<Gtk::Stack>("stack");
   if (!m_stack)
     throw std::runtime_error("No \"stack\" object in window.ui");
 
-  m_refBuilder->get_widget("search", m_search);
+  m_search = m_refBuilder->get_widget<Gtk::ToggleButton>("search");
   if (!m_search)
     throw std::runtime_error("No \"search\" object in window.ui");
 
-  m_refBuilder->get_widget("searchbar", m_searchbar);
+  m_searchbar = m_refBuilder->get_widget<Gtk::SearchBar>("searchbar");
   if (!m_searchbar)
     throw std::runtime_error("No \"searchbar\" object in window.ui");
 
-  m_refBuilder->get_widget("searchentry", m_searchentry);
+  m_searchentry = m_refBuilder->get_widget<Gtk::SearchEntry>("searchentry");
   if (!m_searchentry)
     throw std::runtime_error("No \"searchentry\" object in window.ui");
 
@@ -63,8 +63,7 @@ ExampleAppWindow* ExampleAppWindow::create()
   // Load the Builder file and instantiate its widgets.
   auto refBuilder = Gtk::Builder::create_from_resource("/org/gtkmm/exampleapp/window.ui");
 
-  ExampleAppWindow* window = nullptr;
-  Gtk::Builder::get_widget_derived(refBuilder, "app_window", window);
+  auto window = Gtk::Builder::get_widget_derived<ExampleAppWindow>(refBuilder, "app_window");
   if (!window)
     throw std::runtime_error("No \"app_window\" object in window.ui");
 
@@ -73,7 +72,7 @@ ExampleAppWindow* ExampleAppWindow::create()
 
 void ExampleAppWindow::open_file_view(const Glib::RefPtr<Gio::File>& file)
 {
-  const auto basename = file->get_basename();
+  const Glib::ustring basename = file->get_basename();
 
   auto scrolled = Gtk::make_managed<Gtk::ScrolledWindow>();
   scrolled->set_hexpand(true);
