@@ -36,39 +36,39 @@ ExampleAppWindow::ExampleAppWindow(BaseObjectType* cobject,
   m_binding_lines_visible()
 {
   // Get widgets from the Gtk::Builder file.
-  m_refBuilder->get_widget("stack", m_stack);
+  m_stack = m_refBuilder->get_widget<Gtk::Stack>("stack");
   if (!m_stack)
     throw std::runtime_error("No \"stack\" object in window.ui");
 
-  m_refBuilder->get_widget("search", m_search);
+  m_search = m_refBuilder->get_widget<Gtk::ToggleButton>("search");
   if (!m_search)
     throw std::runtime_error("No \"search\" object in window.ui");
 
-  m_refBuilder->get_widget("searchbar", m_searchbar);
+  m_searchbar = m_refBuilder->get_widget<Gtk::SearchBar>("searchbar");
   if (!m_searchbar)
     throw std::runtime_error("No \"searchbar\" object in window.ui");
 
-  m_refBuilder->get_widget("searchentry", m_searchentry);
+  m_searchentry = m_refBuilder->get_widget<Gtk::SearchEntry>("searchentry");
   if (!m_searchentry)
     throw std::runtime_error("No \"searchentry\" object in window.ui");
 
-  m_refBuilder->get_widget("gears", m_gears);
+  m_gears = m_refBuilder->get_widget<Gtk::MenuButton>("gears");
   if (!m_gears)
     throw std::runtime_error("No \"gears\" object in window.ui");
 
-  m_refBuilder->get_widget("sidebar", m_sidebar);
+  m_sidebar = m_refBuilder->get_widget<Gtk::Revealer>("sidebar");
   if (!m_sidebar)
     throw std::runtime_error("No \"sidebar\" object in window.ui");
 
-  m_refBuilder->get_widget("words", m_words);
+  m_words = m_refBuilder->get_widget<Gtk::ListBox>("words");
   if (!m_words)
     throw std::runtime_error("No \"words\" object in window.ui");
 
-  m_refBuilder->get_widget("lines", m_lines);
+  m_lines = m_refBuilder->get_widget<Gtk::Label>("lines");
   if (!m_lines)
     throw std::runtime_error("No \"lines\" object in window.ui");
 
-  m_refBuilder->get_widget("lines_label", m_lines_label);
+  m_lines_label = m_refBuilder->get_widget<Gtk::Label>("lines_label");
   if (!m_lines_label)
     throw std::runtime_error("No \"lines_label\" object in window.ui");
 
@@ -93,8 +93,7 @@ ExampleAppWindow::ExampleAppWindow(BaseObjectType* cobject,
   // to the win.show-words action and the "Words" menu item.
   // (The connection between action and menu item is specified in gears_menu.ui.)
   auto menu_builder = Gtk::Builder::create_from_resource("/org/gtkmm/exampleapp/gears_menu.ui");
-  auto object = menu_builder->get_object("menu");
-  auto menu = std::dynamic_pointer_cast<Gio::MenuModel>(object);
+  auto menu = menu_builder->get_object<Gio::MenuModel>("menu");
   if (!menu)
     throw std::runtime_error("No \"menu\" object in gears_menu.ui");
 
@@ -114,7 +113,7 @@ ExampleAppWindow::ExampleAppWindow(BaseObjectType* cobject,
   set_show_menubar(true);
 
   // Set the window icon.
-  Gtk::IconTheme::get_default()->add_resource_path("/org/gtkmm/exampleapp");
+  Gtk::IconTheme::get_for_display(get_display())->add_resource_path("/org/gtkmm/exampleapp");
   set_icon_name("exampleapp");
 }
 
@@ -124,8 +123,7 @@ ExampleAppWindow* ExampleAppWindow::create()
   // Load the Builder file and instantiate its widgets.
   auto refBuilder = Gtk::Builder::create_from_resource("/org/gtkmm/exampleapp/window.ui");
 
-  ExampleAppWindow* window = nullptr;
-  Gtk::Builder::get_widget_derived(refBuilder, "app_window", window);
+  auto window = Gtk::Builder::get_widget_derived<ExampleAppWindow>(refBuilder, "app_window");
   if (!window)
     throw std::runtime_error("No \"app_window\" object in window.ui");
 
@@ -134,7 +132,7 @@ ExampleAppWindow* ExampleAppWindow::create()
 
 void ExampleAppWindow::open_file_view(const Glib::RefPtr<Gio::File>& file)
 {
-  const auto basename = file->get_basename();
+  const Glib::ustring basename = file->get_basename();
 
   auto scrolled = Gtk::make_managed<Gtk::ScrolledWindow>();
   scrolled->set_hexpand(true);
