@@ -18,6 +18,9 @@
 #include <iostream>
 #include <cstring>
 
+// Not really used anywhere, but force an instance to be created.
+DerivedButton* my_globally_accessible_button = nullptr;
+
 int main (int argc, char **argv)
 {
   bool show_icon = false;
@@ -41,6 +44,10 @@ int main (int argc, char **argv)
 
   auto app = Gtk::Application::create("org.gtkmm.example");
 
+  // Create a dummy instance before the call to refBuilder->add_from_file().
+  // This creation registers DerivedButton's class in the GType system.
+  my_globally_accessible_button = new DerivedButton();
+
   //Load the Glade file and instantiate its widgets:
   auto refBuilder = Gtk::Builder::create();
   try
@@ -66,10 +73,9 @@ int main (int argc, char **argv)
   //Get the GtkBuilder-instantiated dialog:
   DerivedDialog* pDialog = nullptr;
   if (show_icon)
-    // This call to get_widget_derived() requires gtkmm 3.19.7 or higher.
-    Gtk::Builder::get_widget_derived(refBuilder, "DialogDerived", pDialog, is_glad);
+    pDialog = Gtk::Builder::get_widget_derived<DerivedDialog>(refBuilder, "DialogDerived", is_glad);
   else
-    Gtk::Builder::get_widget_derived(refBuilder, "DialogDerived", pDialog);
+    pDialog = Gtk::Builder::get_widget_derived<DerivedDialog>(refBuilder, "DialogDerived");
   if(pDialog)
   {
     //Start:
