@@ -1,5 +1,3 @@
-//$Id: buttons.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,14 +22,12 @@ Buttons::Buttons()
   m_button.add_pixlabel("info.xpm", "cool button");
 
   set_title("Pixmap'd buttons!");
-  set_border_width(10);
 
   m_button.signal_clicked().connect( sigc::mem_fun(*this,
               &Buttons::on_button_clicked) );
 
+  m_button.set_margin(10);
   add(m_button);
-
-  show_all_children();
 }
 
 Buttons::~Buttons()
