@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,14 +21,12 @@ ExampleWindow::ExampleWindow()
 : m_button("something")
 {
   set_title("togglebutton example");
-  set_border_width(10);
 
   m_button.signal_clicked().connect( sigc::mem_fun(*this,
               &ExampleWindow::on_button_clicked) );
 
+  m_button.set_margin(10);
   add(m_button);
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
