@@ -1,5 +1,3 @@
-//$Id: buttons.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,21 +24,19 @@ ExampleWindow::ExampleWindow()
   set_default_size(300, 300);
 
   set_title("VolumeButton Example");
-  set_border_width(12);
 
+  m_grid.set_margin(12);
   add(m_grid);
   m_button.set_vexpand(true);
   m_button.set_hexpand(true);
 
   m_grid.attach(m_button, 1, 1, 1, 1);
-  m_button.set_valign(Gtk::ALIGN_END);
-  m_button.set_halign(Gtk::ALIGN_END);
+  m_button.set_valign(Gtk::Align::END);
+  m_button.set_halign(Gtk::Align::END);
 
   m_button.set_value(0.4);
   m_button.signal_value_changed().connect(
     sigc::mem_fun(*this, &ExampleWindow::on_value_changed));
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
