@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,44 +15,45 @@
  */
 
 #include "examplewindow.h"
+#include <iostream>
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Label("Select cells in the grid, click Copy, then open a second "
         "instance of this example to try pasting the copied data."),
   m_ButtonA1("A1"), m_ButtonA2("A2"), m_ButtonB1("B1"), m_ButtonB2("B2"),
   m_Button_Copy("_Copy", /* mnemonic= */ true), m_Button_Paste("_Paste", true)
 {
   set_title("Gtk::Clipboard example");
-  set_border_width(12);
 
+  m_VBox.set_margin(12);
   add(m_VBox);
 
-  m_VBox.pack_start(m_Label, Gtk::PACK_SHRINK);
+  m_VBox.add(m_Label);
 
   //Fill Grid:
-  m_VBox.pack_start(m_Grid);
+  m_VBox.add(m_Grid);
+  m_Grid.set_expand(true);
   m_Grid.set_row_homogeneous(true);
   m_Grid.set_column_homogeneous(true);
-  m_Grid.attach(m_ButtonA1, 0, 0, 1, 1);
-  m_Grid.attach(m_ButtonA2, 1, 0, 1, 1);
-  m_Grid.attach(m_ButtonB1, 0, 1, 1, 1);
-  m_Grid.attach(m_ButtonB2, 1, 1, 1, 1);
+  m_Grid.attach(m_ButtonA1, 0, 0);
+  m_Grid.attach(m_ButtonA2, 1, 0);
+  m_Grid.attach(m_ButtonB1, 0, 1);
+  m_Grid.attach(m_ButtonB2, 1, 1);
 
   //Add ButtonBox to bottom:
-  m_VBox.pack_start(m_ButtonBox, Gtk::PACK_SHRINK);
+  m_VBox.add(m_ButtonBox);
   m_VBox.set_spacing(6);
 
   //Fill ButtonBox:
-  m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
-  m_ButtonBox.pack_start(m_Button_Copy, Gtk::PACK_SHRINK);
+  m_ButtonBox.add(m_Button_Copy);
+  m_Button_Copy.set_hexpand(true);
+  m_Button_Copy.set_halign(Gtk::Align::END);
   m_Button_Copy.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_copy) );
-  m_ButtonBox.pack_start(m_Button_Paste, Gtk::PACK_SHRINK);
+  m_ButtonBox.add(m_Button_Paste);
   m_Button_Paste.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_paste) );
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
@@ -71,20 +70,31 @@ void ExampleWindow::on_button_copy()
   strData += m_ButtonB1.get_active() ? "1" : "0";
   strData += m_ButtonB2.get_active() ? "1" : "0";
 
-  auto refClipboard = Gtk::Clipboard::get();
-  refClipboard->set_text(strData);
+  get_clipboard()->set_text(strData);
 }
 
 void ExampleWindow::on_button_paste()
 {
   //Tell the clipboard to call our method when it is ready:
-  auto refClipboard = Gtk::Clipboard::get();
-  refClipboard->request_text(sigc::mem_fun(*this,
-              &ExampleWindow::on_clipboard_text_received) );
+  get_clipboard()->read_text_async(sigc::mem_fun(*this,
+              &ExampleWindow::on_clipboard_text_received));
 }
 
-void ExampleWindow::on_clipboard_text_received(const Glib::ustring& text)
+void ExampleWindow::on_clipboard_text_received(Glib::RefPtr<Gio::AsyncResult>& result)
 {
+  Glib::ustring text;
+  try
+  {
+    text = get_clipboard()->read_text_finish(result);
+  }
+  catch (const Glib::Error& err)
+  {
+    // Print an error about why pasting failed.
+    // Usually you probably want to ignore such failures,
+    // but for demonstration purposes, we show the error.
+    std::cout << "Pasting failed: " << err.what() << std::endl;
+  }
+
   //See comment in on_button_copy() about this silly clipboard format.
   if(text.size() >= 4)
   {
