@@ -1,5 +1,3 @@
-//$Id: examplewindow.h 705 2006-07-19 02:55:32Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,7 +29,8 @@ protected:
   //Signal handlers:
   void on_button_copy();
   void on_button_paste();
-  void on_clipboard_text_received(const Glib::ustring& text);
+
+  void on_clipboard_text_received(Glib::RefPtr<Gio::AsyncResult>& result);
 
   //Child widgets:
   Gtk::Box m_VBox;
@@ -41,7 +40,7 @@ protected:
   Gtk::Grid m_Grid;
   Gtk::ToggleButton m_ButtonA1, m_ButtonA2, m_ButtonB1, m_ButtonB2;
 
-  Gtk::ButtonBox m_ButtonBox;
+  Gtk::Box m_ButtonBox;
   Gtk::Button m_Button_Copy, m_Button_Paste;
 };
 
