@@ -1,5 +1,3 @@
-//$Id: main.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,13 +19,13 @@
 
 int main(int argc, char *argv[])
 {
-  //APPLICATION_NON_UNIQUE because it shall be possible to run several
-  //instances of this application simultaneously.
-  Glib::RefPtr<Gtk::Application> app = Gtk::Application::create(
-    argc, argv, "org.gtkmm.example", Gio::APPLICATION_NON_UNIQUE);
+  // Gio::Application::Flags::NON_UNIQUE because it shall be possible to run
+  // several instances of this application simultaneously.
+  auto app = Gtk::Application::create(
+    "org.gtkmm.example", Gio::Application::Flags::NON_UNIQUE);
 
   ExampleWindow window;
 
   //Shows the window and returns when it is closed.
-  return app->run(window);
+  return app->run(window, argc, argv);
 }
