@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 838 2007-05-10 01:35:59Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -30,11 +28,11 @@ ExampleWindow::ExampleWindow()
   m_Combo.set_model(m_refTreeModel);
 
   //Fill the ComboBox's Tree Model:
-  Gtk::TreeModel::Row row = *(m_refTreeModel->append());
+  auto row = *(m_refTreeModel->append());
   row[m_Columns.m_col_id] = "1";
   row[m_Columns.m_col_name] = "Billy Bob";
   /*
-  Gtk::TreeModel::Row childrow = *(m_refTreeModel->append(row.children()));
+  auto childrow = *(m_refTreeModel->append(row.children()));
   childrow[m_Columns.m_col_id] = 11;
   childrow[m_Columns.m_col_name] = "Billy Bob Junior";
 
@@ -60,7 +58,7 @@ ExampleWindow::ExampleWindow()
   //Add the model columns to the Combo (which is a kind of view),
   //rendering them in the default way:
   //This is automatically rendered when we use set_entry_text_column().
-  //m_Combo.pack_start(m_Columns.m_col_id);
+  //m_Combo.pack_start(m_Columns.m_col_id, Gtk::PackOptions::EXPAND_WIDGET);
   m_Combo.pack_start(m_Columns.m_col_name);
 
   m_Combo.set_entry_text_column(m_Columns.m_col_id);
@@ -70,31 +68,36 @@ ExampleWindow::ExampleWindow()
   add(m_Combo);
 
   //Connect signal handlers:
+  m_Combo.signal_changed().connect(sigc::mem_fun(*this, &ExampleWindow::on_combo_changed));
+
   auto entry = m_Combo.get_entry();
   if (entry)
   {
-    // The Entry shall receive focus-out events.
-    entry->add_events(Gdk::FOCUS_CHANGE_MASK);
-    // Alternatively you can connect to m_Combo.signal_changed().
     entry->signal_changed().connect(sigc::mem_fun(*this,
       &ExampleWindow::on_entry_changed) );
-    entry->signal_activate().connect(sigc::mem_fun(*this,
-      &ExampleWindow::on_entry_activate) );
-    m_ConnectionFocusOut = entry->signal_focus_out_event().
-      connect(sigc::mem_fun(*this, &ExampleWindow::on_entry_focus_out_event) );
+    m_ConnectionHasFocusChanged = entry->property_has_focus().signal_changed().
+      connect(sigc::mem_fun(*this, &ExampleWindow::on_entry_has_focus_changed));
   }
   else
     std::cout << "No Entry ???" << std::endl;
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
 {
-  // The focus_out signal may be emitted while m_Combo is being destructed.
+  // The has_focus changed signal may be emitted while m_Combo is being destructed.
   // The signal handler can generate critical messages, if it's called when
   // m_Combo has been partly destructed.
-  m_ConnectionFocusOut.disconnect();
+  m_ConnectionHasFocusChanged.disconnect();
+}
+
+void ExampleWindow::on_combo_changed()
+{
+  auto entry = m_Combo.get_entry();
+  if (entry)
+  {
+    std::cout << "on_combo_changed(): Row=" << m_Combo.get_active_row_number()
+      << ", ID=" << entry->get_text() << std::endl;
+  }
 }
 
 void ExampleWindow::on_entry_changed()
@@ -107,24 +110,18 @@ void ExampleWindow::on_entry_changed()
   }
 }
 
-void ExampleWindow::on_entry_activate()
+void ExampleWindow::on_entry_has_focus_changed()
 {
   auto entry = m_Combo.get_entry();
   if (entry)
   {
-    std::cout << "on_entry_activate(): Row=" << m_Combo.get_active_row_number()
-      << ", ID=" << entry->get_text() << std::endl;
+    const bool entry_has_focus = entry->has_focus();
+    if (m_entry_had_focus && !entry_has_focus)
+    {
+      // entry->has_focus() has changed from true to false; entry has lost focus.
+      std::cout << "on_entry_has_focus_changed() to not focused: Row="
+        << m_Combo.get_active_row_number() << ", ID=" << entry->get_text() << std::endl;
+    }
+    m_entry_had_focus = entry_has_focus;
   }
 }
-
-bool ExampleWindow::on_entry_focus_out_event(GdkEventFocus* /* event */)
-{
-  auto entry = m_Combo.get_entry();
-  if (entry)
-  {
-    std::cout << "on_entry_focus_out_event(): Row=" << m_Combo.get_active_row_number()
-      << ", ID=" << entry->get_text() << std::endl;
-    return true;
-  }
-  return false;
-}
