@@ -1,5 +1,3 @@
-//$Id: examplewindow.h 398 2005-04-19 14:42:11Z murrayc $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,12 +29,13 @@ public:
 
 protected:
   //Signal handlers:
+  void on_combo_changed();
   void on_entry_changed();
-  void on_entry_activate();
-  bool on_entry_focus_out_event(GdkEventFocus* event);
+  void on_entry_has_focus_changed();
 
   //Signal connection:
-  sigc::connection m_ConnectionFocusOut;
+  sigc::connection m_ConnectionHasFocusChanged;
+  bool m_entry_had_focus {false};
 
   //Tree model columns:
   class ModelColumns : public Gtk::TreeModel::ColumnRecord
