@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,32 +31,29 @@ ExampleWindow::ExampleWindow()
   add(m_Combo);
 
   //Connect signal handlers:
-  auto entry = m_Combo.get_entry();
-  // Alternatively you can connect to entry->signal_changed().
   m_Combo.signal_changed().connect(sigc::mem_fun(*this,
     &ExampleWindow::on_combo_changed) );
+
+  auto entry = m_Combo.get_entry();
   if (entry)
   {
-    // The Entry shall receive focus-out events.
-    entry->add_events(Gdk::FOCUS_CHANGE_MASK);
-    entry->signal_activate().connect(sigc::mem_fun(*this,
-      &ExampleWindow::on_entry_activate) );
-    m_ConnectionFocusOut = entry->signal_focus_out_event().
-      connect(sigc::mem_fun(*this, &ExampleWindow::on_entry_focus_out_event) );
+    entry->signal_changed().connect(sigc::mem_fun(*this,
+      &ExampleWindow::on_entry_changed));
+    m_ConnectionHasFocusChanged = entry->property_has_focus().signal_changed().
+      connect(sigc::mem_fun(*this, &ExampleWindow::on_entry_has_focus_changed));
   }
   else
     std::cout << "No Entry ???" << std::endl;
 
   m_Combo.property_has_frame() = false;
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
 {
-  // The focus_out signal may be emitted while m_Combo is being destructed.
+  // The has_focus changed signal may be emitted while m_Combo is being destructed.
   // The signal handler can generate critical messages, if it's called when
   // m_Combo has been partly destructed.
-  m_ConnectionFocusOut.disconnect();
+  m_ConnectionHasFocusChanged.disconnect();
 }
 
 void ExampleWindow::on_combo_changed()
@@ -67,15 +62,24 @@ void ExampleWindow::on_combo_changed()
     << ", Text=" << m_Combo.get_active_text() << std::endl;
 }
 
-void ExampleWindow::on_entry_activate()
+void ExampleWindow::on_entry_changed()
 {
-  std::cout << "on_entry_activate(): Row=" << m_Combo.get_active_row_number()
+  std::cout << "on_entry_changed(): Row=" << m_Combo.get_active_row_number()
     << ", Text=" << m_Combo.get_active_text() << std::endl;
 }
 
-bool ExampleWindow::on_entry_focus_out_event(GdkEventFocus* /* event */)
+void ExampleWindow::on_entry_has_focus_changed()
 {
-  std::cout << "on_entry_focus_out_event(): Row=" << m_Combo.get_active_row_number()
-    << ", Text=" << m_Combo.get_active_text() << std::endl;
-  return true;
+  auto entry = m_Combo.get_entry();
+  if (entry)
+  {
+    const bool entry_has_focus = entry->has_focus();
+    if (m_entry_had_focus && !entry_has_focus)
+    {
+      // entry->has_focus() has changed from true to false; entry has lost focus.
+      std::cout << "on_entry_has_focus_changed() to not focused: Row="
+        << m_Combo.get_active_row_number() << ", ID=" << entry->get_text() << std::endl;
+    }
+    m_entry_had_focus = entry_has_focus;
+  }
 }
