@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2004 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,30 +18,30 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Button_One("Child One"),
-  m_Label_Two("Child 2", Gtk::ALIGN_END, Gtk::ALIGN_CENTER),
+  m_Label_Two("Child 2", Gtk::Align::END, Gtk::Align::CENTER),
   m_Button_Quit("Quit")
 {
   set_title("Custom Container example");
-  set_border_width(6);
   set_default_size(400, 200);
 
+  m_VBox.set_margin(6);
   add(m_VBox);
 
   //Add the child widgets to the custom container:
   m_MyContainer.set_child_widgets(m_Button_One, m_Label_Two);
+  m_MyContainer.set_expand();
 
-  m_VBox.pack_start(m_MyContainer, Gtk::PACK_EXPAND_WIDGET);
-  m_VBox.pack_start(m_ButtonBox, Gtk::PACK_SHRINK);
+  m_VBox.add(m_MyContainer);
+  m_VBox.add(m_ButtonBox);
 
-  m_ButtonBox.pack_start(m_Button_Quit, Gtk::PACK_SHRINK);
-  m_ButtonBox.set_border_width(6);
-  m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
+  m_ButtonBox.add(m_Button_Quit);
+  m_ButtonBox.set_margin(6);
+  m_Button_Quit.set_hexpand(true);
+  m_Button_Quit.set_halign(Gtk::Align::END);
   m_Button_Quit.signal_clicked().connect( sigc::mem_fun(*this,
               &ExampleWindow::on_button_quit) );
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
