@@ -18,7 +18,7 @@
 #include <iostream>
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL, 5),
+: m_VBox(Gtk::Orientation::VERTICAL, 5),
   m_Button_Dialog("Choose Color")
 {
   set_title("Gtk::ColorChooserDialog example");
@@ -26,11 +26,11 @@ ExampleWindow::ExampleWindow()
 
   add(m_VBox);
 
-  m_VBox.pack_start(m_ColorButton, Gtk::PACK_SHRINK);
+  m_VBox.add(m_ColorButton);
   m_ColorButton.signal_color_set().connect(sigc::mem_fun(*this,
     &ExampleWindow::on_color_button_color_set) );
 
-  m_VBox.pack_start(m_Button_Dialog, Gtk::PACK_SHRINK);
+  m_VBox.add(m_Button_Dialog);
   m_Button_Dialog.signal_clicked().connect(sigc::mem_fun(*this,
     &ExampleWindow::on_button_dialog_clicked) );
 
@@ -41,11 +41,9 @@ ExampleWindow::ExampleWindow()
   m_Color.set_alpha(1.0); //opaque
   m_ColorButton.set_rgba(m_Color);
 
-  m_VBox.pack_start(m_DrawingArea);
-  m_DrawingArea.signal_draw().connect(sigc::mem_fun(*this,
-    &ExampleWindow::on_drawing_area_draw));
-
-  show_all_children();
+  m_VBox.add(m_DrawingArea);
+  m_DrawingArea.set_expand(true);
+  m_DrawingArea.set_draw_func(sigc::mem_fun(*this, &ExampleWindow::on_drawing_area_draw));
 }
 
 ExampleWindow::~ExampleWindow()
@@ -71,14 +69,14 @@ void ExampleWindow::on_button_dialog_clicked()
   //Handle the response:
   switch(result)
   {
-    case Gtk::RESPONSE_OK:
+    case Gtk::ResponseType::OK:
     {
       //Store the chosen color:
       m_Color = dialog.get_rgba();
       m_ColorButton.set_rgba(m_Color);
       break;
     }
-    case Gtk::RESPONSE_CANCEL:
+    case Gtk::ResponseType::CANCEL:
     {
       std::cout << "Cancel clicked." << std::endl;
       break;
@@ -91,10 +89,8 @@ void ExampleWindow::on_button_dialog_clicked()
   }
 }
 
-bool ExampleWindow::on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr)
+void ExampleWindow::on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr, int, int)
 {
   Gdk::Cairo::set_source_rgba(cr, m_Color);
   cr->paint();
-
-  return true;
 }
