@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +19,7 @@
 
 
 ExampleWindow::ExampleWindow()
-: m_ButtonBox(Gtk::ORIENTATION_VERTICAL),
+: m_ButtonBox(Gtk::Orientation::VERTICAL),
   m_Button_File("Choose File"),
   m_Button_Folder("Choose Folder")
 {
@@ -29,15 +27,15 @@ ExampleWindow::ExampleWindow()
 
   add(m_ButtonBox);
 
-  m_ButtonBox.pack_start(m_Button_File);
+  m_ButtonBox.add(m_Button_File);
+  m_Button_File.set_expand(true);
   m_Button_File.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_file_clicked) );
 
-  m_ButtonBox.pack_start(m_Button_Folder);
+  m_ButtonBox.add(m_Button_Folder);
+  m_Button_Folder.set_expand(true);
   m_Button_Folder.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_folder_clicked) );
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
@@ -47,26 +45,26 @@ ExampleWindow::~ExampleWindow()
 void ExampleWindow::on_button_folder_clicked()
 {
   Gtk::FileChooserDialog dialog("Please choose a folder",
-          Gtk::FILE_CHOOSER_ACTION_SELECT_FOLDER);
+          Gtk::FileChooser::Action::SELECT_FOLDER);
   dialog.set_transient_for(*this);
 
   //Add response buttons the the dialog:
-  dialog.add_button("_Cancel", Gtk::RESPONSE_CANCEL);
-  dialog.add_button("Select", Gtk::RESPONSE_OK);
+  dialog.add_button("_Cancel", Gtk::ResponseType::CANCEL);
+  dialog.add_button("Select", Gtk::ResponseType::OK);
 
   int result = dialog.run();
 
   //Handle the response:
   switch(result)
   {
-    case(Gtk::RESPONSE_OK):
+    case Gtk::ResponseType::OK:
     {
       std::cout << "Select clicked." << std::endl;
       std::cout << "Folder selected: " << dialog.get_filename()
           << std::endl;
       break;
     }
-    case(Gtk::RESPONSE_CANCEL):
+    case Gtk::ResponseType::CANCEL:
     {
       std::cout << "Cancel clicked." << std::endl;
       break;
@@ -82,12 +80,12 @@ void ExampleWindow::on_button_folder_clicked()
 void ExampleWindow::on_button_file_clicked()
 {
   Gtk::FileChooserDialog dialog("Please choose a file",
-          Gtk::FILE_CHOOSER_ACTION_OPEN);
+          Gtk::FileChooser::Action::OPEN);
   dialog.set_transient_for(*this);
 
   //Add response buttons the the dialog:
-  dialog.add_button("_Cancel", Gtk::RESPONSE_CANCEL);
-  dialog.add_button("_Open", Gtk::RESPONSE_OK);
+  dialog.add_button("_Cancel", Gtk::ResponseType::CANCEL);
+  dialog.add_button("_Open", Gtk::ResponseType::OK);
 
   //Add filters, so that only certain file types can be selected:
 
@@ -114,16 +112,16 @@ void ExampleWindow::on_button_file_clicked()
   //Handle the response:
   switch(result)
   {
-    case(Gtk::RESPONSE_OK):
+    case Gtk::ResponseType::OK:
     {
       std::cout << "Open clicked." << std::endl;
 
       //Notice that this is a std::string, not a Glib::ustring.
-      std::string filename = dialog.get_filename();
+      auto filename = dialog.get_filename();
       std::cout << "File selected: " <<  filename << std::endl;
       break;
     }
-    case(Gtk::RESPONSE_CANCEL):
+    case Gtk::ResponseType::CANCEL:
     {
       std::cout << "Cancel clicked." << std::endl;
       break;
