@@ -20,7 +20,7 @@
 
 int main(int argc, char* argv[])
 {
-  auto app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
+  auto app = Gtk::Application::create("org.gtkmm.example");
 
   Gtk::Window window;
   window.set_title("Drawing text example");
@@ -29,5 +29,5 @@ int main(int argc, char* argv[])
   window.add(area);
   area.show();
 
-  return app->run(window);
+  return app->run(window, argc, argv);
 }
