@@ -21,7 +21,7 @@ ExampleWindow::ExampleWindow()
 {
   set_title("Thin lines example");
 
-  m_Container.set_orientation(Gtk::ORIENTATION_HORIZONTAL);
+  m_Container.set_orientation(Gtk::Orientation::HORIZONTAL);
 
   m_Container.add(m_Area_Lines);
   m_Container.add(m_Button_FixLines);
@@ -33,8 +33,6 @@ ExampleWindow::ExampleWindow()
 
   // Synchonize the drawing in m_Area_Lines with the state of the toggle button.
   on_button_toggled();
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
