@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +18,7 @@
 #include <iostream>
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Label("Press a or b to see a list of possible completions and actions."),
   m_Button_Close("Close")
 {
@@ -28,15 +26,15 @@ ExampleWindow::ExampleWindow()
   set_title("Gtk::EntryCompletion");
 
   add(m_VBox);
-  m_VBox.pack_start(m_Entry, Gtk::PACK_SHRINK);
+  m_VBox.add(m_Entry);
 
-  m_VBox.pack_start(m_Label, Gtk::PACK_EXPAND_WIDGET);
+  m_VBox.add(m_Label);
+  m_Label.set_expand(true);
 
   m_Button_Close.signal_clicked().connect( sigc::mem_fun(*this,
               &ExampleWindow::on_button_close) );
-  m_VBox.pack_start(m_Button_Close, Gtk::PACK_SHRINK);
-  m_Button_Close.set_can_default();
-  m_Button_Close.grab_default();
+  m_VBox.add(m_Button_Close);
+  set_default_widget(m_Button_Close);
 
   //Add an EntryCompletion:
   auto completion =
@@ -54,7 +52,7 @@ ExampleWindow::ExampleWindow()
               //&ExampleWindow::on_completion_match) );
 
   //Fill the TreeView's model
-  Gtk::TreeModel::Row row = *(refCompletionModel->append());
+  auto row = *(refCompletionModel->append());
   row[m_Columns.m_col_id] = 1;
   row[m_Columns.m_col_name] = "Alan Zebedee";
 
@@ -93,8 +91,6 @@ ExampleWindow::ExampleWindow()
 
   completion->signal_action_activated().connect( sigc::mem_fun(*this,
               &ExampleWindow::on_completion_action_activated) );
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
@@ -116,12 +112,12 @@ bool ExampleWindow::on_completion_match(const Glib::ustring& key, const
 {
   if(iter)
   {
-    Gtk::TreeModel::Row row = *iter;
+    const auto row = *iter;
 
-    Glib::ustring::size_type key_length = key.size();
-    Glib::ustring filter_string = row[m_Columns.m_col_name];
+    const auto key_length = key.size();
+    auto filter_string = row[m_Columns.m_col_name];
 
-    Glib::ustring filter_string_start = filter_string.substr(0, key_length);
+    auto filter_string_start = filter_string.substr(0, key_length);
     //The key is lower-case, even if the user input is not.
     filter_string_start = filter_string_start.lowercase();
 
@@ -135,10 +131,10 @@ bool ExampleWindow::on_completion_match(const Glib::ustring& key, const
 
 void ExampleWindow::on_completion_action_activated(int index)
 {
-  type_actions_map::iterator iter = m_CompletionActions.find(index);
+  auto iter = m_CompletionActions.find(index);
   if(iter != m_CompletionActions.end()) //If it's in the map
   {
-    Glib::ustring title = iter->second;
+    auto title = iter->second;
     std::cout << "Action selected: " << title << std::endl;
   }
 }
