@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +18,7 @@
 #include <iostream>
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Button_Close("Close")
 {
   set_title("Gtk::Entry");
@@ -29,7 +27,7 @@ ExampleWindow::ExampleWindow()
 
   m_Entry.set_max_length(50);
   m_Entry.set_text("Hello world");
-  m_VBox.pack_start(m_Entry, Gtk::PACK_SHRINK);
+  m_VBox.add(m_Entry);
 
   //Change the progress fraction every 0.1 second:
   Glib::signal_timeout().connect(
@@ -39,11 +37,8 @@ ExampleWindow::ExampleWindow()
 
   m_Button_Close.signal_clicked().connect( sigc::mem_fun(*this,
               &ExampleWindow::on_button_close) );
-  m_VBox.pack_start(m_Button_Close, Gtk::PACK_SHRINK);
-  m_Button_Close.set_can_default();
-  m_Button_Close.grab_default();
-
-  show_all_children();
+  m_VBox.add(m_Button_Close);
+  set_default_widget(m_Button_Close);
 }
 
 ExampleWindow::~ExampleWindow()
