@@ -21,14 +21,13 @@ ExampleWindow::ExampleWindow()
   // Window properties
   set_title("FlowBox Example");
   set_default_size(600, 400);
-  set_border_width(6);
 
   // Scrolled window
-  m_scrolled_window.set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
+  m_scrolled_window.set_policy(Gtk::PolicyType::NEVER, Gtk::PolicyType::AUTOMATIC);
 
   // Flow box
   m_flow_box.set_max_children_per_line(30);
-  m_flow_box.set_selection_mode(Gtk::SELECTION_NONE);
+  m_flow_box.set_selection_mode(Gtk::SelectionMode::NONE);
   m_flow_box.set_homogeneous();
 
   // Color swatches
@@ -41,9 +40,8 @@ ExampleWindow::ExampleWindow()
 
   // Layout
   m_scrolled_window.add(m_flow_box);
+  m_scrolled_window.set_margin(6);
   add(m_scrolled_window);
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
@@ -55,22 +53,22 @@ Gtk::Button* ExampleWindow::create_color_swatch(int swatch_i)
   auto drawing_area = Gtk::make_managed<Gtk::DrawingArea>();
   auto color_swatch = Gtk::make_managed<Gtk::Button>();
 
-  drawing_area->set_size_request(24, 24);
+  drawing_area->set_content_width(24);
+  drawing_area->set_content_height(24);
 
   color_swatch->add(*drawing_area);
-  drawing_area->signal_draw().connect(sigc::bind(sigc::mem_fun(*this,
+  drawing_area->set_draw_func(sigc::bind(sigc::mem_fun(*this,
     &ExampleWindow::on_drawing_area_draw), swatch_i));
 
   return color_swatch;
 }
 
-bool ExampleWindow::on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr, int swatch_i)
+void ExampleWindow::on_drawing_area_draw(const Cairo::RefPtr<Cairo::Context>& cr,
+  int, int, int swatch_i)
 {
   Gdk::RGBA rgba(m_color_names[swatch_i]);
   Gdk::Cairo::set_source_rgba(cr, rgba);
   cr->paint();
-
-  return true;
 }
 
 void ExampleWindow::fill_color_names()
