@@ -17,28 +17,27 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
- : m_close_button_label("Show close button:", Gtk::ALIGN_END, Gtk::ALIGN_CENTER),
-   m_title_label("Title:", Gtk::ALIGN_END, Gtk::ALIGN_CENTER),
-   m_subtitle_label("Subtitle:", Gtk::ALIGN_END, Gtk::ALIGN_CENTER)
+ : m_title_buttons_label("Show title buttons:", Gtk::Align::END, Gtk::Align::CENTER),
+   m_title_label("Title:", Gtk::Align::END, Gtk::Align::CENTER),
+   m_subtitle_label("Subtitle:", Gtk::Align::END, Gtk::Align::CENTER)
 {
   // Window properties
   set_title("HeaderBar Example");
-  set_border_width(12);
 
   // Button
-  m_button.set_image_from_icon_name("go-home-symbolic", Gtk::ICON_SIZE_BUTTON, true);
+  m_button.set_image_from_icon_name("go-home-symbolic", Gtk::IconSize::INHERIT, true);
   m_button.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_button_clicked));
 
   // Entries
   m_title_entry.set_text("HeaderBar title");
   m_subtitle_entry.set_text("HeaderBar subtitle");
-  m_title_entry.signal_activate().connect(sigc::mem_fun(*this, &ExampleWindow::on_title_entry_activate));
-  m_subtitle_entry.signal_activate().connect(sigc::mem_fun(*this, &ExampleWindow::on_subtitle_entry_activate));
+  m_title_entry.signal_changed().connect(sigc::mem_fun(*this, &ExampleWindow::on_title_entry_changed));
+  m_subtitle_entry.signal_changed().connect(sigc::mem_fun(*this, &ExampleWindow::on_subtitle_entry_changed));
 
   // Header bar
-  on_title_entry_activate();
-  on_subtitle_entry_activate();
-  m_header_bar.set_show_close_button();
+  on_title_entry_changed();
+  on_subtitle_entry_changed();
+  m_header_bar.set_show_title_buttons();
   m_header_bar.pack_start(m_button);
 
   // Set headerbar as titlebar
@@ -51,15 +50,14 @@ ExampleWindow::ExampleWindow()
   // Layout
   m_grid.set_column_spacing(6);
   m_grid.set_row_spacing(6);
-  m_grid.attach(m_close_button_label, 0, 0, 1, 1);
-  m_grid.attach(m_switch, 1, 0, 1, 1);
-  m_grid.attach(m_title_label, 0, 1, 1, 1);
-  m_grid.attach(m_title_entry, 1, 1, 1, 1);
-  m_grid.attach(m_subtitle_label, 0, 2, 1, 1);
-  m_grid.attach(m_subtitle_entry, 1, 2, 1, 1);
+  m_grid.attach(m_title_buttons_label, 0, 0);
+  m_grid.attach(m_switch, 1, 0);
+  m_grid.attach(m_title_label, 0, 1);
+  m_grid.attach(m_title_entry, 1, 1);
+  m_grid.attach(m_subtitle_label, 0, 2);
+  m_grid.attach(m_subtitle_entry, 1, 2);
+  m_grid.set_margin(12);
   add(m_grid);
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
@@ -68,22 +66,22 @@ ExampleWindow::~ExampleWindow()
 
 void ExampleWindow::on_switch_active_changed()
 {
-  bool show_close_button = m_switch.get_active();
-  m_header_bar.set_show_close_button(show_close_button);
+  bool show_title_buttons = m_switch.get_active();
+  m_header_bar.set_show_title_buttons(show_title_buttons);
 }
 
-void ExampleWindow::on_title_entry_activate()
+void ExampleWindow::on_title_entry_changed()
 {
-  const Glib::ustring title = m_title_entry.get_text();
+  const auto title = m_title_entry.get_text();
   if(!title.empty())
   {
     m_header_bar.set_title(title);
   }
 }
 
-void ExampleWindow::on_subtitle_entry_activate()
+void ExampleWindow::on_subtitle_entry_changed()
 {
-  const Glib::ustring subtitle = m_subtitle_entry.get_text();
+  const auto subtitle = m_subtitle_entry.get_text();
   m_header_bar.set_subtitle(subtitle);
 }
 
