@@ -26,10 +26,10 @@ public:
   virtual ~ExampleWindow();
 
 protected:
-  // Slots
+  // Signal handlers
   void on_switch_active_changed();
-  void on_title_entry_activate();
-  void on_subtitle_entry_activate();
+  void on_title_entry_changed();
+  void on_subtitle_entry_changed();
   void on_button_clicked();
 
   // Containers
@@ -38,7 +38,7 @@ protected:
   // Widgets
   Gtk::HeaderBar m_header_bar;
   Gtk::Button m_button;
-  Gtk::Label m_close_button_label;
+  Gtk::Label m_title_buttons_label;
   Gtk::Switch m_switch;
   Gtk::Label m_title_label;
   Gtk::Entry m_title_entry;
