@@ -37,33 +37,35 @@ namespace
 }
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Button_Quit("Quit")
 {
   set_title("Gtk::IconView (ListStore + TreeModelSort) example");
-  set_border_width(5);
   set_default_size(400, 400);
 
-  add( m_VBox );
+  m_VBox.set_margin(5);
+  add(m_VBox);
 
   // Add the TreeView inside a ScrolledWindow, with the button underneath:
   m_ScrolledWindow.add(m_IconView);
 
   // Only show the scrollbars when they are necessary:
-  m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+  m_ScrolledWindow.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
+  m_ScrolledWindow.set_expand();
 
-  m_VBox.pack_start(m_ScrolledWindow);
-  m_VBox.pack_start(m_ButtonBox, Gtk::PACK_SHRINK);
+  m_VBox.add(m_ScrolledWindow);
+  m_VBox.add(m_ButtonBox);
 
-  m_ButtonBox.pack_start(m_Button_Quit, Gtk::PACK_SHRINK);
-  m_ButtonBox.set_border_width(6);
-  m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
+  m_ButtonBox.add(m_Button_Quit);
+  m_ButtonBox.set_margin(6);
+  m_Button_Quit.set_hexpand(true);
+  m_Button_Quit.set_halign(Gtk::Align::END);
   m_Button_Quit.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_quit) );
 
   // Create the Tree model:
   m_refListModel = Gtk::ListStore::create( m_Columns );
-  m_refListModel->set_sort_column( m_Columns.m_col_description, Gtk::SORT_ASCENDING );
+  m_refListModel->set_sort_column( m_Columns.m_col_description, Gtk::SortType::ASCENDING );
 
   m_IconView.set_model(m_refListModel);
   m_IconView.set_markup_column(m_Columns.m_col_description);
@@ -92,8 +94,6 @@ ExampleWindow::ExampleWindow()
   {
     add_entry( entries[idx].m_filename, entries[idx].m_description );
   }
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
@@ -109,8 +109,8 @@ void ExampleWindow::on_button_quit()
 
 void ExampleWindow::on_item_activated(const Gtk::TreeModel::Path& path)
 {
-  Gtk::TreeModel::iterator iter = m_refListModel->get_iter(path);
-  Gtk::TreeModel::Row row = *iter;
+  auto iter = m_refListModel->get_iter(path);
+  auto row = *iter;
 
   const std::string filename = row[m_Columns.m_col_filename];
   const Glib::ustring description = row[m_Columns.m_col_description];
@@ -130,8 +130,8 @@ void ExampleWindow::on_selection_changed()
   if(!selected.empty())
   {
     const Gtk::TreeModel::Path& path = *selected.begin();
-    Gtk::TreeModel::iterator iter = m_refListModel->get_iter(path);
-    Gtk::TreeModel::Row row = *iter;
+    auto iter = m_refListModel->get_iter(path);
+    auto row = *iter;
 
     const std::string filename = row[m_Columns.m_col_filename];
     const Glib::ustring description = row[m_Columns.m_col_description];
@@ -145,22 +145,24 @@ void ExampleWindow::on_selection_changed()
 }
 
 void ExampleWindow::add_entry(const std::string& filename,
-        const Glib::ustring& description)
+        const Glib::ustring& description )
 {
+  auto row = *(m_refListModel->append());
+  row[m_Columns.m_col_filename] = filename;
+  row[m_Columns.m_col_description] = description;
+
   try
   {
-    auto pixbuf = Gdk::Pixbuf::create_from_file(filename);
-    Gtk::TreeModel::Row row = *(m_refListModel->append());
-    row[m_Columns.m_col_filename] = filename;
-    row[m_Columns.m_col_description] = description;
-    row[m_Columns.m_col_pixbuf] = pixbuf;
+    row[m_Columns.m_col_pixbuf] = Gdk::Pixbuf::create_from_file(filename);
   }
-  catch (const Glib::FileError& err)
+  catch (const Gdk::PixbufError& ex)
   {
-    std::cout << "Glib::FileError: " << err.what() << std::endl;
+    std::cerr << "Gdk::PixbufError: " << ex.what() << std::endl;
   }
-  catch (const Gdk::PixbufError& err)
+  catch (const Glib::FileError& ex)
   {
-    std::cout << "Gdk::PixbufError: " << err.what() << std::endl;
+    std::cerr << "Glib::FileError: " << ex.what() << std::endl;
   }
 }
+
+
