@@ -17,14 +17,14 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL, 6),
+: m_VBox(Gtk::Orientation::VERTICAL, 6),
   m_Button_Quit("_Quit", true),
   m_Button_Clear("_Clear", true)
 {
   set_title("Gtk::InfoBar example");
-  set_border_width(6);
   set_default_size(400, 200);
 
+  m_VBox.set_margin(6);
   add(m_VBox);
 
   // Add the message label to the InfoBar:
@@ -37,7 +37,7 @@ ExampleWindow::ExampleWindow()
   m_InfoBar.add_button("_OK", 0);
 
   // Add the InfoBar to the vbox:
-  m_VBox.pack_start(m_InfoBar, Gtk::PACK_SHRINK);
+  m_VBox.add(m_InfoBar);
 
   // Create the buffer and set it for the TextView:
   m_refTextBuffer = Gtk::TextBuffer::create();
@@ -47,17 +47,19 @@ ExampleWindow::ExampleWindow()
   m_ScrolledWindow.add(m_TextView);
 
   // Show the scrollbars only when they are necessary:
-  m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+  m_ScrolledWindow.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
+  m_ScrolledWindow.set_expand();
 
-  m_VBox.pack_start(m_ScrolledWindow);
+  m_VBox.add(m_ScrolledWindow);
 
   // Add button box:
-  m_VBox.pack_start(m_ButtonBox, Gtk::PACK_SHRINK);
+  m_VBox.add(m_ButtonBox);
 
-  m_ButtonBox.pack_start(m_Button_Clear, Gtk::PACK_SHRINK);
-  m_ButtonBox.pack_start(m_Button_Quit, Gtk::PACK_SHRINK);
+  m_ButtonBox.add(m_Button_Clear);
+  m_ButtonBox.add(m_Button_Quit);
   m_ButtonBox.set_spacing(6);
-  m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
+  m_Button_Clear.set_hexpand(true);
+  m_Button_Clear.set_halign(Gtk::Align::END);
 
   // Connect signals:
   m_InfoBar.signal_response().connect(sigc::mem_fun(*this,
@@ -69,8 +71,6 @@ ExampleWindow::ExampleWindow()
   m_refTextBuffer->signal_changed().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_textbuffer_changed) );
 
-  show_all();
-
   // Keep the InfoBar hidden until a message needs to be shown:
   m_InfoBar.hide();
 
@@ -100,7 +100,7 @@ void ExampleWindow::on_button_clear()
 {
   m_refTextBuffer->set_text("");
   m_Message_Label.set_text("Cleared the text.");
-  m_InfoBar.set_message_type(Gtk::MESSAGE_INFO);
+  m_InfoBar.set_message_type(Gtk::MessageType::INFO);
   m_InfoBar.show();
 }
 
