@@ -27,19 +27,18 @@ public:
   virtual ~ExampleWindow();
 
 private:
-  //Override default signal handler:
-  bool on_key_release_event(GdkEventKey* event) override;
-
-  bool entryKeyRelease(GdkEventKey* event);
-  bool gridKeyRelease(GdkEventKey* event);
-  bool windowKeyReleaseBefore(GdkEventKey* event);
-  bool windowKeyRelease(GdkEventKey* event);
+  // Signal handlers:
+  bool label2_key_pressed(guint keyval, guint keycode, Gdk::ModifierType state, const Glib::ustring& phase);
+  bool grid_key_pressed(guint keyval, guint keycode, Gdk::ModifierType state, const Glib::ustring& phase);
+  bool window_key_pressed(guint keyval, guint keycode, Gdk::ModifierType state, const Glib::ustring& phase);
 
+  bool m_first = true;
   Gtk::Grid m_container;
-
-  Gtk::Label m_label;
-  Gtk::Entry m_entry;
-  Gtk::CheckButton m_checkbutton_can_propagate;
+  Gtk::Frame m_frame;
+  Gtk::Label m_label1;
+  Gtk::Label m_label2;
+  Gtk::CheckButton m_checkbutton_can_propagate_down;
+  Gtk::CheckButton m_checkbutton_can_propagate_up;
 };
 
 #endif //GTKMM_EVENT_PROPAGATION_H
