@@ -26,24 +26,24 @@ struct SelectionModeStruct
 
 const SelectionModeStruct selectionModes[] =
 {
-  { Gtk::SELECTION_NONE,   "SELECTION_NONE" },
-  { Gtk::SELECTION_SINGLE, "SELECTION_SINGLE" },
-  { Gtk::SELECTION_BROWSE, "SELECTION_BROWSE" }
+  { Gtk::SelectionMode::NONE,   "SelectionMode::NONE" },
+  { Gtk::SelectionMode::SINGLE, "SelectionMode::SINGLE" },
+  { Gtk::SelectionMode::BROWSE, "SelectionMode::BROWSE" }
 };
 
 } // anonymous namespace
 
 ExampleWindow::ExampleWindow() :
-  m_HBox(Gtk::ORIENTATION_HORIZONTAL),
-  m_VBox1(Gtk::ORIENTATION_VERTICAL),
-  m_VBox2(Gtk::ORIENTATION_VERTICAL),
+  m_HBox(Gtk::Orientation::HORIZONTAL),
+  m_VBox1(Gtk::Orientation::VERTICAL),
+  m_VBox2(Gtk::Orientation::VERTICAL),
   m_ListBox(),
   m_ComboBox(/* has_entry= */ false),
   m_CheckButton_SingleClick("single click mode", /* mnemonic= */ false),
   m_ScrolledWindow(),
   m_Row3("blah3", 3),
-  m_VBox_Row(Gtk::ORIENTATION_VERTICAL),
-  m_HBox_Row(Gtk::ORIENTATION_HORIZONTAL),
+  m_VBox_Row(Gtk::Orientation::VERTICAL),
+  m_HBox_Row(Gtk::Orientation::HORIZONTAL),
   m_Label_Row("a check box"),
   m_CheckButton_Row1(),
   m_CheckButton_Row2(),
@@ -60,20 +60,20 @@ ExampleWindow::ExampleWindow() :
   m_Button_Visibility("visibility")
 {
   set_title("ListBox example");
-  set_border_width(5);
   set_default_size(300, 300);
 
+  m_HBox.set_margin(5);
   add(m_HBox);
-  m_HBox.pack_start(m_VBox1, Gtk::PACK_SHRINK);
+  m_HBox.add(m_VBox1);
 
   // ComboBox for selection mode.
   for (std::size_t i = 0; i < G_N_ELEMENTS(selectionModes); ++i)
     m_ComboBox.append(selectionModes[i].text);
 
   m_ComboBox.signal_changed().connect(sigc::mem_fun(*this, &ExampleWindow::on_selection_mode_changed));
-  m_VBox1.pack_start(m_ComboBox, Gtk::PACK_SHRINK);
+  m_VBox1.add(m_ComboBox);
 
-  const Gtk::SelectionMode mode = m_ListBox.get_selection_mode();
+  const auto mode = m_ListBox.get_selection_mode();
   int index = 0;
   for (std::size_t i = 0; i < G_N_ELEMENTS(selectionModes); ++i)
   {
@@ -88,12 +88,12 @@ ExampleWindow::ExampleWindow() :
   // Check button for single click.
   m_CheckButton_SingleClick.set_active(m_ListBox.get_activate_on_single_click());
   m_CheckButton_SingleClick.signal_toggled().connect(sigc::mem_fun(*this, &ExampleWindow::on_single_click_toggled));
-  m_VBox1.pack_start(m_CheckButton_SingleClick, Gtk::PACK_SHRINK);
+  m_VBox1.add(m_CheckButton_SingleClick);
 
   // Put the ListBox in a ScrolledWindow.
-  m_ScrolledWindow.set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
+  m_ScrolledWindow.set_policy(Gtk::PolicyType::NEVER, Gtk::PolicyType::AUTOMATIC);
   m_ScrolledWindow.add(m_ListBox);
-  m_HBox.pack_start(m_ScrolledWindow, Gtk::PACK_SHRINK);
+  m_HBox.add(m_ScrolledWindow);
 
   m_ListBox.signal_row_selected().connect(sigc::mem_fun(*this, &ExampleWindow::on_row_selected));
   m_ListBox.signal_row_activated().connect(sigc::mem_fun(*this, &ExampleWindow::on_row_activated));
@@ -108,42 +108,40 @@ ExampleWindow::ExampleWindow() :
   m_ListBox.append(*row);
 
   row = Gtk::make_managed<ExampleRow>("", 0);
-  m_HBox_Row.pack_start(m_Label_Row, Gtk::PACK_SHRINK);
-  m_HBox_Row.pack_start(m_CheckButton_Row1, Gtk::PACK_SHRINK);
-  m_HBox_Row.pack_start(m_Button_Row1, Gtk::PACK_SHRINK);
-  m_VBox_Row.pack_start(m_HBox_Row, Gtk::PACK_SHRINK);
-  m_VBox_Row.pack_start(m_CheckButton_Row2, Gtk::PACK_SHRINK);
+  m_HBox_Row.add(m_Label_Row);
+  m_HBox_Row.add(m_CheckButton_Row1);
+  m_HBox_Row.add(m_Button_Row1);
+  m_VBox_Row.add(m_HBox_Row);
+  m_VBox_Row.add(m_CheckButton_Row2);
   row->add(m_VBox_Row);
   m_ListBox.append(*row);
 
   row = Gtk::make_managed<ExampleRow>("", 0);
   m_Button_Row2.set_hexpand(false);
-  m_Button_Row2.set_halign(Gtk::ALIGN_START);
+  m_Button_Row2.set_halign(Gtk::Align::START);
   row->add(m_Button_Row2);
   m_ListBox.append(*row);
 
   // Put buttons in a vertical box, and connect signal handlers.
-  m_HBox.pack_start(m_VBox2, Gtk::PACK_SHRINK);
-  m_VBox2.pack_start(m_Button_Sort, Gtk::PACK_SHRINK);
+  m_HBox.add(m_VBox2);
+  m_VBox2.add(m_Button_Sort);
   m_Button_Sort.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_sort_clicked));
-  m_VBox2.pack_start(m_Button_ReverseSort, Gtk::PACK_SHRINK);
+  m_VBox2.add(m_Button_ReverseSort);
   m_Button_ReverseSort.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_reverse_sort_clicked));
-  m_VBox2.pack_start(m_Button_Change, Gtk::PACK_SHRINK);
+  m_VBox2.add(m_Button_Change);
   m_Button_Change.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_change_clicked));
-  m_VBox2.pack_start(m_Button_Filter, Gtk::PACK_SHRINK);
+  m_VBox2.add(m_Button_Filter);
   m_Button_Filter.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_filter_clicked));
-  m_VBox2.pack_start(m_Button_Unfilter, Gtk::PACK_SHRINK);
+  m_VBox2.add(m_Button_Unfilter);
   m_Button_Unfilter.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_unfilter_clicked));
-  m_VBox2.pack_start(m_Button_Add, Gtk::PACK_SHRINK);
+  m_VBox2.add(m_Button_Add);
   m_Button_Add.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_add_clicked));
-  m_VBox2.pack_start(m_Button_Separate, Gtk::PACK_SHRINK);
+  m_VBox2.add(m_Button_Separate);
   m_Button_Separate.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_separate_clicked));
-  m_VBox2.pack_start(m_Button_Unseparate, Gtk::PACK_SHRINK);
+  m_VBox2.add(m_Button_Unseparate);
   m_Button_Unseparate.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_unseparate_clicked));
-  m_VBox2.pack_start(m_Button_Visibility, Gtk::PACK_SHRINK);
+  m_VBox2.add(m_Button_Visibility);
   m_Button_Visibility.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_visibility_clicked));
-
-  show_all_children();
 }
 
 void ExampleWindow::on_selection_mode_changed()
@@ -228,7 +226,6 @@ void ExampleWindow::on_add_clicked()
   static int new_button_nr = 1;
   const Glib::ustring text = "blah2 new " + Glib::ustring::format(new_button_nr);
   auto new_row = Gtk::make_managed<ExampleRow>(text, new_button_nr);
-  new_row->show_all();
   m_ListBox.append(*new_row);
   ++new_button_nr;
 }
@@ -251,12 +248,11 @@ void ExampleWindow::update_header_func(Gtk::ListBoxRow* row, Gtk::ListBoxRow* be
     // Create header if needed.
     if (!row->get_header())
     {
-      auto hbox = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_HORIZONTAL);
+      auto hbox = Gtk::make_managed<Gtk::Box>(Gtk::Orientation::HORIZONTAL);
       auto label = Gtk::make_managed<Gtk::Label>("Header");
-      hbox->pack_start(*label, Gtk::PACK_SHRINK);
+      hbox->add(*label);
       auto button = Gtk::make_managed<Gtk::Button>("button");
-      hbox->pack_start(*button, Gtk::PACK_SHRINK);
-      hbox->show_all();
+      hbox->add(*button);
       row->set_header(*hbox);
     }
 
