@@ -27,18 +27,18 @@ m_button_remove_some("_Remove some", true),
 m_button_quit("_Quit", true)
 {
   set_title("ListBox and FlowBox with ListModel");
-  set_border_width(5);
   set_default_size(300, 300);
 
   for (int i = 0; i < 20; ++i)
   {
-    const Glib::ustring label = Glib::ustring::format("Item ", i);
+    const auto label = Glib::ustring::format("Item ", i);
     m_store->append(MyObject::create(i, label));
   }
 
   // Use current time as seed for random number generator.
   std::srand(std::time(nullptr));
 
+  m_grid.set_margin(5);
   add(m_grid);
 
   // Select bind_model() or bind_list_store() randomly.
@@ -46,7 +46,7 @@ m_button_quit("_Quit", true)
   std::cout << "Using bind_" << (use_bind_model ? "model" : "list_store") << std::endl;
 
   // A ListBox to the left.
-  m_scrolled_window_list_box.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+  m_scrolled_window_list_box.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
   m_scrolled_window_list_box.set_hexpand(true);
   m_scrolled_window_list_box.set_vexpand(true);
   m_grid.attach(m_scrolled_window_list_box, 0, 0, 1 ,1);
@@ -57,7 +57,7 @@ m_button_quit("_Quit", true)
     m_list_box.bind_list_store(m_store, sigc::ptr_fun(&ExampleWindow::on_create_widget2));
 
   // A FlowBox to the right.
-  m_scrolled_window_flow_box.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+  m_scrolled_window_flow_box.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
   m_scrolled_window_flow_box.set_hexpand(true);
   m_scrolled_window_flow_box.set_vexpand(true);
   m_grid.attach(m_scrolled_window_flow_box, 1, 0, 1 ,1);
@@ -74,14 +74,12 @@ m_button_quit("_Quit", true)
   m_grid.attach(m_button_remove_some, 0, 2, 2, 1);
   m_button_quit.signal_clicked().connect(sigc::mem_fun(*this, &ExampleWindow::on_quit));
   m_grid.attach(m_button_quit, 0, 3, 2, 1);
-
-  show_all_children();
 }
 
 // static
 Gtk::Widget* ExampleWindow::on_create_widget1(const Glib::RefPtr<Glib::Object>& item)
 {
-  auto obj = Glib::RefPtr<MyObject>::cast_dynamic(item);
+  auto obj = std::dynamic_pointer_cast<MyObject>(item);
   if (!obj)
   {
     std::cout << "on_create_widget1(): item is not a MyObject" << std::endl;
@@ -89,7 +87,7 @@ Gtk::Widget* ExampleWindow::on_create_widget1(const Glib::RefPtr<Glib::Object>&
   }
   auto label = Gtk::make_managed<Gtk::Label>();
   Glib::Binding::bind_property(obj->property_label(), label->property_label(),
-    Glib::BINDING_SYNC_CREATE);
+    Glib::Binding::Flags::SYNC_CREATE);
   return label;
 }
 
@@ -103,7 +101,7 @@ Gtk::Widget* ExampleWindow::on_create_widget2(const Glib::RefPtr<MyObject>& item
   }
   auto label = Gtk::make_managed<Gtk::Label>();
   Glib::Binding::bind_property(item->property_label(), label->property_label(),
-    Glib::BINDING_SYNC_CREATE);
+    Glib::Binding::Flags::SYNC_CREATE);
   return label;
 }
 
@@ -113,7 +111,7 @@ void ExampleWindow::on_add_some()
   {
     const auto n_items = m_store->get_n_items();
     const auto i = std::rand() % std::max(2*n_items, 4u);
-    const Glib::ustring label = Glib::ustring::format("Added ", i);
+    const auto label = Glib::ustring::format("Added ", i);
     m_store->insert_sorted(MyObject::create(i, label),
       sigc::ptr_fun(&MyObject::compare));
   }
