@@ -200,9 +200,9 @@ void ExampleApplication::on_startup()
 
   //Get the menubar and the app menu, and add them to the application:
   auto object = m_refBuilder->get_object("menu-example");
-  auto gmenu = Glib::RefPtr<Gio::Menu>::cast_dynamic(object);
+  auto gmenu = std::dynamic_pointer_cast<Gio::Menu>(object);
   object = m_refBuilder->get_object("appmenu");
-  auto appMenu = Glib::RefPtr<Gio::Menu>::cast_dynamic(object);
+  auto appMenu = std::dynamic_pointer_cast<Gio::Menu>(object);
   if (!(gmenu && appMenu)) {
     g_warning("GMenu or AppMenu not found");
   }
@@ -231,10 +231,10 @@ void ExampleApplication::create_window()
 
   //Delete the window when it is hidden.
   //That's enough for this simple example.
-  win->signal_hide().connect(sigc::bind<Gtk::Window*>(
+  win->signal_hide().connect(sigc::bind(
     sigc::mem_fun(*this, &ExampleApplication::on_window_hide), win));
 
-  win->show_all();
+  win->show();
 }
 
 void ExampleApplication::on_window_hide(Gtk::Window* window)
