@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,11 +17,11 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
-: m_VPaned(Gtk::ORIENTATION_VERTICAL)
+: m_VPaned(Gtk::Orientation::VERTICAL)
 {
   set_title ("Paned Windows");
-  set_border_width(10);
   set_default_size(450, 400);
+  m_VPaned.set_margin(10);
 
   /* Add a vpaned widget to our toplevel window */
   add(m_VPaned);
@@ -31,8 +29,6 @@ ExampleWindow::ExampleWindow()
   /* Now add the contents of the two halves of the window */
   m_VPaned.add1(m_MessagesList);
   m_VPaned.add2(m_MessageText);
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
