@@ -1,5 +1,3 @@
-//$Id: messageslist.cc 2 2003-01-21 13:41:59Z murrayc $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,7 +20,7 @@
 MessagesList::MessagesList()
 {
   /* Create a new scrolled window, with scrollbars only if needed */
-  set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+  set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
 
   add(m_TreeView);
 
@@ -37,14 +35,12 @@ MessagesList::MessagesList()
     std::ostringstream text;
     text << "message #" << i;
 
-    Gtk::TreeModel::Row row = *(m_refListStore->append());
+    auto row = *(m_refListStore->append());
     row[m_Columns.m_col_text] = text.str();
   }
 
   //Add the Model's column to the View's columns:
   m_TreeView.append_column("Messages", m_Columns.m_col_text);
-
-  show_all_children();
 }
 
 MessagesList::~MessagesList()
