@@ -1,5 +1,3 @@
-//$Id: messagetext.cc 2 2003-01-21 13:41:59Z murrayc $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,12 +18,10 @@
 
 MessageText::MessageText()
 {
-  set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+  set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
 
   add(m_TextView);
   insert_text();
-
-  show_all_children();
 }
 
 MessageText::~MessageText()
@@ -36,7 +32,7 @@ void MessageText::insert_text()
 {
   auto refTextBuffer = m_TextView.get_buffer();
 
-  Gtk::TextBuffer::iterator iter = refTextBuffer->get_iter_at_offset(0);
+  auto iter = refTextBuffer->get_iter_at_offset(0);
   refTextBuffer->insert(iter,
     "From: pathfinder@nasa.gov\n"
     "To: mom@nasa.gov\n"
