@@ -120,7 +120,7 @@ void PrintFormOperation::on_draw_page(
   cairo_ctx->set_source_rgb(0, 0, 0);
 
   //Render Pango LayoutLines over the Cairo context:
-  Pango::LayoutIter iter = m_refLayout->get_iter();
+  auto iter = m_refLayout->get_iter();
 
   double start_pos = 0;
   int line_index = 0;
@@ -130,7 +130,7 @@ void PrintFormOperation::on_draw_page(
     if(line_index >= start_page_line)
     {
       auto layout_line = iter.get_line();
-      Pango::Rectangle logical_rect = iter.get_line_logical_extents();
+      auto logical_rect = iter.get_line_logical_extents();
       int baseline = iter.get_baseline();
 
       if (line_index == start_page_line)
@@ -154,21 +154,18 @@ Gtk::Widget* PrintFormOperation::on_create_custom_widget()
   //Create a custom tab in the print dialog titled "Other"
   set_custom_tab_label("Other");
 
-  auto vbox = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_VERTICAL);
-  vbox->set_border_width(12);
+  auto vbox = Gtk::make_managed<Gtk::Box>(Gtk::Orientation::VERTICAL);
+  vbox->set_margin(12);
 
-  auto hbox = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_HORIZONTAL, 8);
-  vbox->pack_start(*hbox, false, false);
-  hbox->set_border_width(6);
-  hbox->show();
+  auto hbox = Gtk::make_managed<Gtk::Box>(Gtk::Orientation::HORIZONTAL, 8);
+  vbox->add(*hbox);
+  hbox->set_margin(6);
 
   auto label = Gtk::make_managed<Gtk::Label>("Choose a font: ");
-  hbox->pack_start(*label, false, false);
-  label->show();
+  hbox->add(*label);
 
-  m_FontButton.set_font_name(m_Font);
-  hbox->pack_start(m_FontButton, false, false);
-  m_FontButton.show();
+  m_FontButton.set_font(m_Font);
+  hbox->add(m_FontButton);
 
   return vbox;
 }
@@ -179,7 +176,7 @@ void PrintFormOperation::on_custom_widget_apply(Gtk::Widget*)
   // on_create_custom_widget().  We don't need to use it, because we can use the
   // child FontButton directly:
 
-  Glib::ustring selected_font = m_FontButton.get_font_name();
+  auto selected_font = m_FontButton.get_font();
   m_Font = selected_font;
 }
 
