@@ -19,13 +19,13 @@
 
 ExampleWindow::ExampleWindow()
 :
-  m_VBox_Top(Gtk::ORIENTATION_VERTICAL, 0),
-  m_VBox2(Gtk::ORIENTATION_VERTICAL, 20),
-  m_VBox_HScale(Gtk::ORIENTATION_VERTICAL, 10),
-  m_HBox_Scales(Gtk::ORIENTATION_HORIZONTAL, 10),
-  m_HBox_Combo(Gtk::ORIENTATION_HORIZONTAL, 10),
-  m_HBox_Digits(Gtk::ORIENTATION_HORIZONTAL, 10),
-  m_HBox_PageSize(Gtk::ORIENTATION_HORIZONTAL, 10),
+  m_VBox_Top(Gtk::Orientation::VERTICAL, 0),
+  m_VBox2(Gtk::Orientation::VERTICAL, 20),
+  m_VBox_HScale(Gtk::Orientation::VERTICAL, 10),
+  m_HBox_Scales(Gtk::Orientation::HORIZONTAL, 10),
+  m_HBox_Combo(Gtk::Orientation::HORIZONTAL, 10),
+  m_HBox_Digits(Gtk::Orientation::HORIZONTAL, 10),
+  m_HBox_PageSize(Gtk::Orientation::HORIZONTAL, 10),
 
   // Value, lower, upper, step_increment, page_increment, page_size:
   // Note that the page_size value only makes a difference for
@@ -35,8 +35,8 @@ ExampleWindow::ExampleWindow()
   m_adjustment_digits( Gtk::Adjustment::create(1.0, 0.0, 5.0, 1.0, 2.0) ),
   m_adjustment_pagesize( Gtk::Adjustment::create(1.0, 1.0, 101.0) ),
 
-  m_VScale(m_adjustment, Gtk::ORIENTATION_VERTICAL),
-  m_HScale(m_adjustment, Gtk::ORIENTATION_HORIZONTAL),
+  m_VScale(m_adjustment, Gtk::Orientation::VERTICAL),
+  m_HScale(m_adjustment, Gtk::Orientation::HORIZONTAL),
   m_Scale_Digits(m_adjustment_digits),
   m_Scale_PageSize(m_adjustment_pagesize),
 
@@ -55,34 +55,40 @@ ExampleWindow::ExampleWindow()
 
   //VScale:
   m_VScale.set_digits(1);
-  m_VScale.set_value_pos(Gtk::POS_TOP);
+  m_VScale.set_value_pos(Gtk::PositionType::TOP);
   m_VScale.set_draw_value();
   m_VScale.set_inverted(); // highest value at top
 
   //HScale:
   m_HScale.set_digits(1);
-  m_HScale.set_value_pos(Gtk::POS_TOP);
+  m_HScale.set_value_pos(Gtk::PositionType::TOP);
   m_HScale.set_draw_value();
 
   add(m_VBox_Top);
-  m_VBox_Top.pack_start(m_VBox2);
-  m_VBox2.set_border_width(10);
-  m_VBox2.pack_start(m_HBox_Scales);
+  m_VBox_Top.add(m_VBox2);
+  m_VBox2.set_expand(true);
+  m_VBox2.set_margin(10);
+  m_VBox2.add(m_HBox_Scales);
+  m_HBox_Scales.set_expand(true);
 
   //Put VScale and HScale (above scrollbar) side-by-side.
-  m_HBox_Scales.pack_start(m_VScale);
-  m_HBox_Scales.pack_start(m_VBox_HScale);
+  m_HBox_Scales.add(m_VScale);
+  m_VScale.set_expand(true);
+  m_HBox_Scales.add(m_VBox_HScale);
+  m_VBox_HScale.set_expand(true);
 
-  m_VBox_HScale.pack_start(m_HScale);
+  m_VBox_HScale.add(m_HScale);
+  m_HScale.set_expand(true);
 
   //Scrollbar:
-  m_VBox_HScale.pack_start(m_Scrollbar);
+  m_VBox_HScale.add(m_Scrollbar);
+  m_Scrollbar.set_expand(true);
 
   //CheckButton:
   m_CheckButton.set_active();
   m_CheckButton.signal_toggled().connect( sigc::mem_fun(*this,
     &ExampleWindow::on_checkbutton_toggled) );
-  m_VBox2.pack_start(m_CheckButton, Gtk::PACK_SHRINK);
+  m_VBox2.add(m_CheckButton);
 
   //Position ComboBox:
   //Create the Tree model:
@@ -91,55 +97,51 @@ ExampleWindow::ExampleWindow()
   m_ComboBox_Position.pack_start(m_Columns.m_col_title);
 
   //Fill the ComboBox's Tree Model:
-  Gtk::TreeModel::Row row = *(m_refTreeModel->append());
-  row[m_Columns.m_col_position_type] = Gtk::POS_TOP;
+  auto row = *(m_refTreeModel->append());
+  row[m_Columns.m_col_position_type] = Gtk::PositionType::TOP;
   row[m_Columns.m_col_title] = "Top";
   row = *(m_refTreeModel->append());
-  row[m_Columns.m_col_position_type] = Gtk::POS_BOTTOM;
+  row[m_Columns.m_col_position_type] = Gtk::PositionType::BOTTOM;
   row[m_Columns.m_col_title] = "Bottom";
   row = *(m_refTreeModel->append());
-  row[m_Columns.m_col_position_type] = Gtk::POS_LEFT;
+  row[m_Columns.m_col_position_type] = Gtk::PositionType::LEFT;
   row[m_Columns.m_col_title] = "Left";
   row = *(m_refTreeModel->append());
-  row[m_Columns.m_col_position_type] = Gtk::POS_RIGHT;
+  row[m_Columns.m_col_position_type] = Gtk::PositionType::RIGHT;
   row[m_Columns.m_col_title] = "Right";
 
-  m_VBox2.pack_start(m_HBox_Combo, Gtk::PACK_SHRINK);
-  m_HBox_Combo.pack_start(
-    *Gtk::make_managed<Gtk::Label>("Scale Value Position:", 0), Gtk::PACK_SHRINK);
-  m_HBox_Combo.pack_start(m_ComboBox_Position);
+  m_VBox2.add(m_HBox_Combo);
+  m_HBox_Combo.add(*Gtk::make_managed<Gtk::Label>("Scale Value Position:", 0));
+  m_HBox_Combo.add(m_ComboBox_Position);
   m_ComboBox_Position.signal_changed().connect( sigc::mem_fun(*this, &ExampleWindow::on_combo_position) );
   m_ComboBox_Position.set_active(0); // Top
+  m_ComboBox_Position.set_expand(true);
 
   //Digits:
-  m_HBox_Digits.pack_start(
-    *Gtk::make_managed<Gtk::Label>("Scale Digits:", 0), Gtk::PACK_SHRINK);
+  m_HBox_Digits.add(*Gtk::make_managed<Gtk::Label>("Scale Digits:", 0));
   m_Scale_Digits.set_digits(0);
+  m_Scale_Digits.set_expand(true);
   m_adjustment_digits->signal_value_changed().connect(sigc::mem_fun(*this,
     &ExampleWindow::on_adjustment1_value_changed));
-  m_HBox_Digits.pack_start(m_Scale_Digits);
+  m_HBox_Digits.add(m_Scale_Digits);
 
   //Page Size:
-  m_HBox_PageSize.pack_start(
-    *Gtk::make_managed<Gtk::Label>("Scrollbar Page Size:", 0),
-    Gtk::PACK_SHRINK);
+  m_HBox_PageSize.add(*Gtk::make_managed<Gtk::Label>("Scrollbar Page Size:", 0));
   m_Scale_PageSize.set_digits(0);
+  m_Scale_PageSize.set_expand(true);
   m_adjustment_pagesize->signal_value_changed().connect(sigc::mem_fun(*this,
     &ExampleWindow::on_adjustment2_value_changed));
-  m_HBox_PageSize.pack_start(m_Scale_PageSize);
+  m_HBox_PageSize.add(m_Scale_PageSize);
 
-  m_VBox2.pack_start(m_HBox_Digits, Gtk::PACK_SHRINK);
-  m_VBox2.pack_start(m_HBox_PageSize, Gtk::PACK_SHRINK);
-  m_VBox_Top.pack_start(m_Separator, Gtk::PACK_SHRINK);
-  m_VBox_Top.pack_start(m_Button_Quit, Gtk::PACK_SHRINK);
+  m_VBox2.add(m_HBox_Digits);
+  m_VBox2.add(m_HBox_PageSize);
+  m_VBox_Top.add(m_Separator);
+  m_VBox_Top.add(m_Button_Quit);
 
-  m_Button_Quit.set_can_default();
-  m_Button_Quit.grab_default();
+  set_default_widget(m_Button_Quit);
   m_Button_Quit.signal_clicked().connect(sigc::mem_fun(*this,
     &ExampleWindow::on_button_quit));
-  m_Button_Quit.set_border_width(10);
-
-  show_all_children();
+  m_Button_Quit.set_margin(10);
 }
 
 ExampleWindow::~ExampleWindow()
@@ -154,15 +156,15 @@ void ExampleWindow::on_checkbutton_toggled()
 
 void ExampleWindow::on_combo_position()
 {
-  Gtk::TreeModel::iterator iter = m_ComboBox_Position.get_active();
+  const auto iter = m_ComboBox_Position.get_active();
   if(!iter)
     return;
 
-  Gtk::TreeModel::Row row = *iter;
+  const auto row = *iter;
   if(!row)
     return;
 
-  const Gtk::PositionType postype = row[m_Columns.m_col_position_type];
+  const auto postype = row[m_Columns.m_col_position_type];
 
   m_VScale.set_value_pos(postype);
   m_HScale.set_value_pos(postype);
