@@ -24,7 +24,7 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
   set_title("Recent files example");
   set_default_size(300, 150);
 
-  //We can put a MenuBar at the top of the box and other stuff below it.
+  //We can put a PopoverMenuBar at the top of the box and other stuff below it.
   add(m_Box);
 
   //Create actions for menus and toolbars:
@@ -77,26 +77,24 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
     "      </item>"
     "    </submenu>"
     "  </menu>"
-    "  <object class='GtkToolbar' id='toolbar'>"
+    "  <object class='GtkBox' id='toolbar'>"
     "    <property name='can_focus'>False</property>"
     "    <child>"
-    "      <object class='GtkToolButton' id='toolbutton_new'>"
+    "      <object class='GtkButton' id='toolbutton_new'>"
     "        <property name='can_focus'>False</property>"
     "        <property name='tooltip_text' translatable='yes'>New</property>"
     "        <property name='action_name'>example.new</property>"
     "        <property name='icon_name'>document-new</property>"
     "        <property name='expand'>False</property>"
-    "        <property name='homogeneous'>True</property>"
     "      </object>"
     "    </child>"
     "    <child>"
-    "      <object class='GtkToolButton' id='toolbutton_quit'>"
+    "      <object class='GtkButton' id='toolbutton_quit'>"
     "        <property name='can_focus'>False</property>"
     "        <property name='tooltip_text' translatable='yes'>Quit</property>"
     "        <property name='action_name'>example.quit</property>"
     "        <property name='icon_name'>application-exit</property>"
     "        <property name='expand'>False</property>"
-    "        <property name='homogeneous'>True</property>"
     "      </object>"
     "    </child>"
     "  </object>"
@@ -117,19 +115,18 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
   if (gmenu)
   {
     //Menubar:
-    auto pMenubar = Gtk::make_managed<Gtk::MenuBar>(gmenu);
+    auto pMenubar = Gtk::make_managed<Gtk::PopoverMenuBar>(gmenu);
     m_Box.add(*pMenubar);
   }
   else
     g_warning("GMenu not found");
 
-  Gtk::Toolbar* pToolbar = nullptr;
-  m_refBuilder->get_widget("toolbar", pToolbar);
+  auto pToolbar = m_refBuilder->get_widget<Gtk::Box>("toolbar");
   if (pToolbar)
     //Toolbar:
     m_Box.add(*pToolbar);
   else
-    g_warning("GtkToolbar not found");
+    g_warning("toolbar not found");
 }
 
 ExampleWindow::~ExampleWindow()
