@@ -19,11 +19,11 @@
 
 int main(int argc, char *argv[])
 {
-  auto app = Gtk::Application::create(argc, argv, "org.gtkmm.example.revealer");
+  auto app = Gtk::Application::create("org.gtkmm.example.revealer");
 
   ExampleWindow window;
 
   // Shows the window and returns when it is closed.
-  return app->run(window);
+  return app->run(window, argc, argv);
 }
 
