@@ -20,19 +20,19 @@
 ExampleWindow::ExampleWindow()
 {
   set_title("Gtk::ScrolledWindow example");
-  set_border_width(0);
   set_size_request(300, 300);
 
-  m_ScrolledWindow.set_border_width(10);
+  m_ScrolledWindow.set_margin(10);
 
-  /* the policy is one of Gtk::POLICY AUTOMATIC, or Gtk::POLICY_ALWAYS.
-   * Gtk::POLICY_AUTOMATIC will automatically decide whether you need
-   * scrollbars, whereas Gtk::POLICY_ALWAYS will always leave the scrollbars
+  /* the policy is one of Gtk::PolicyType::AUTOMATIC, or Gtk::PolicyType::ALWAYS.
+   * Gtk::PolicyType::AUTOMATIC will automatically decide whether you need
+   * scrollbars, whereas Gtk::PolicyType::ALWAYS will always leave the scrollbars
    * there.  The first one is the horizontal scrollbar, the second,
    * the vertical. */
-  m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS);
+  m_ScrolledWindow.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::ALWAYS);
+  m_ScrolledWindow.set_expand();
 
-  get_content_area()->pack_start(m_ScrolledWindow);
+  get_content_area()->add(m_ScrolledWindow);
 
   /* set the spacing to 10 on x and 10 on y */
   m_Grid.set_row_spacing(10);
@@ -50,19 +50,17 @@ ExampleWindow::ExampleWindow()
         char buffer[32];
         sprintf(buffer, "button (%d,%d)\n", i, j);
         auto pButton = Gtk::make_managed<Gtk::ToggleButton>(buffer);
-        m_Grid.attach(*pButton, i, j);
+        m_Grid.attach(*pButton, i, j, 1, 1);
      }
   }
 
   /* Add a "close" button to the bottom of the dialog */
-  add_button("_Close", Gtk::RESPONSE_CLOSE);
+  add_button("_Close", Gtk::ResponseType::CLOSE);
   signal_response().connect(sigc::mem_fun(*this, &ExampleWindow::on_dialog_response));
 
   /* This makes it so the button is the default.
    * Simply hitting the "Enter" key will cause this button to activate. */
-  set_default_response(Gtk::RESPONSE_CLOSE);
-
-  show_all_children();
+  set_default_response(Gtk::ResponseType::CLOSE);
 }
 
 ExampleWindow::~ExampleWindow()
@@ -73,8 +71,8 @@ void ExampleWindow::on_dialog_response(int response_id)
 {
   switch (response_id)
   {
-  case Gtk::RESPONSE_CLOSE:
-  case Gtk::RESPONSE_DELETE_EVENT:
+  case Gtk::ResponseType::CLOSE:
+  case Gtk::ResponseType::DELETE_EVENT:
     hide();
     break;
   default:
