@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,34 +17,36 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Button_Quit("_Quit", true),
   m_Button_Buffer1("Use buffer 1"),
   m_Button_Buffer2("Use buffer 2")
 {
   set_title("Gtk::TextView example");
-  set_border_width(5);
   set_default_size(400, 200);
 
+  m_VBox.set_margin(5);
   add(m_VBox);
 
   //Add the TreeView, inside a ScrolledWindow, with the button underneath:
   m_ScrolledWindow.add(m_TextView);
 
   //Only show the scrollbars when they are necessary:
-  m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+  m_ScrolledWindow.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
+  m_ScrolledWindow.set_expand();
 
-  m_VBox.pack_start(m_ScrolledWindow);
+  m_VBox.add(m_ScrolledWindow);
 
   //Add buttons:
-  m_VBox.pack_start(m_ButtonBox, Gtk::PACK_SHRINK);
+  m_VBox.add(m_ButtonBox);
 
-  m_ButtonBox.pack_start(m_Button_Buffer1, Gtk::PACK_SHRINK);
-  m_ButtonBox.pack_start(m_Button_Buffer2, Gtk::PACK_SHRINK);
-  m_ButtonBox.pack_start(m_Button_Quit, Gtk::PACK_SHRINK);
-  m_ButtonBox.set_border_width(5);
+  m_Button_Buffer1.set_hexpand(true);
+  m_Button_Buffer1.set_halign(Gtk::Align::END);
+  m_ButtonBox.add(m_Button_Buffer1);
+  m_ButtonBox.add(m_Button_Buffer2);
+  m_ButtonBox.add(m_Button_Quit);
+  m_ButtonBox.set_margin(5);
   m_ButtonBox.set_spacing(5);
-  m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
 
   //Connect signals:
   m_Button_Quit.signal_clicked().connect(sigc::mem_fun(*this,
@@ -58,8 +58,6 @@ ExampleWindow::ExampleWindow()
 
   fill_buffers();
   on_button_buffer1();
-
-  show_all_children();
 }
 
 void ExampleWindow::fill_buffers()
