@@ -18,27 +18,29 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Button_Quit("Quit")
 {
   set_title("Gtk::TreeView (ListStore) example");
-  set_border_width(5);
   set_default_size(400, 200);
 
+  m_VBox.set_margin(5);
   add(m_VBox);
 
   //Add the TreeView, inside a ScrolledWindow, with the button underneath:
   m_ScrolledWindow.add(m_TreeView);
 
   //Only show the scrollbars when they are necessary:
-  m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+  m_ScrolledWindow.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
+  m_ScrolledWindow.set_expand();
 
-  m_VBox.pack_start(m_ScrolledWindow);
-  m_VBox.pack_start(m_ButtonBox, Gtk::PACK_SHRINK);
+  m_VBox.add(m_ScrolledWindow);
+  m_VBox.add(m_ButtonBox);
 
-  m_ButtonBox.pack_start(m_Button_Quit, Gtk::PACK_SHRINK);
-  m_ButtonBox.set_border_width(5);
-  m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
+  m_ButtonBox.add(m_Button_Quit);
+  m_ButtonBox.set_margin(5);
+  m_Button_Quit.set_hexpand(true);
+  m_Button_Quit.set_halign(Gtk::Align::END);
   m_Button_Quit.signal_clicked().connect( sigc::mem_fun(*this,
               &ExampleWindow::on_button_quit) );
 
@@ -46,7 +48,7 @@ ExampleWindow::ExampleWindow()
   //You could also use set_cell_data_func() to choose or fill these later.
   m_refTreeModelCombo1 = Gtk::ListStore::create(m_ColumnsCombo);
 
-  Gtk::TreeModel::Row row = *(m_refTreeModelCombo1->append());
+  auto row = *(m_refTreeModelCombo1->append());
   row[m_ColumnsCombo.m_col_choice] = "abc";
   row = *(m_refTreeModelCombo1->append());
   row[m_ColumnsCombo.m_col_choice] = "def";
@@ -120,8 +122,6 @@ ExampleWindow::ExampleWindow()
 
   pRenderer->signal_edited().connect( sigc::mem_fun(*this,
               &ExampleWindow::on_cellrenderer_choice_edited) );
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
@@ -139,11 +139,11 @@ void ExampleWindow::on_cellrenderer_choice_edited(
   Gtk::TreePath path(path_string);
 
   //Get the row from the path:
-  Gtk::TreeModel::iterator iter = m_refTreeModel->get_iter(path);
+  auto iter = m_refTreeModel->get_iter(path);
   if(iter)
   {
       //Store the user's new text in the model:
-      Gtk::TreeRow row = *iter;
+      auto row = *iter;
       row[m_Columns.m_col_itemchosen] = new_text;
   }
 }
