@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,27 +18,29 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
-: m_VBox(Gtk::ORIENTATION_VERTICAL),
+: m_VBox(Gtk::Orientation::VERTICAL),
   m_Button_Quit("_Quit", true)
 {
   set_title("Gtk::TreeView (Drag and Drop) example");
-  set_border_width(5);
   set_default_size(400, 200);
 
+  m_VBox.set_margin(5);
   add(m_VBox);
 
   //Add the TreeView, inside a ScrolledWindow, with the button underneath:
   m_ScrolledWindow.add(m_TreeView);
 
   //Only show the scrollbars when they are necessary:
-  m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+  m_ScrolledWindow.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
+  m_ScrolledWindow.set_expand();
 
-  m_VBox.pack_start(m_ScrolledWindow);
-  m_VBox.pack_start(m_ButtonBox, Gtk::PACK_SHRINK);
+  m_VBox.add(m_ScrolledWindow);
+  m_VBox.add(m_ButtonBox);
 
-  m_ButtonBox.pack_start(m_Button_Quit, Gtk::PACK_SHRINK);
-  m_ButtonBox.set_border_width(5);
-  m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
+  m_ButtonBox.add(m_Button_Quit);
+  m_ButtonBox.set_margin(5);
+  m_Button_Quit.set_hexpand(true);
+  m_Button_Quit.set_halign(Gtk::Align::END);
   m_Button_Quit.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_quit) );
 
@@ -57,13 +57,13 @@ ExampleWindow::ExampleWindow()
   m_TreeView.enable_model_drag_dest();
 
   //Fill the TreeView's model
-  Gtk::TreeModel::Row row = *(m_refTreeModel->append());
+  auto row = *(m_refTreeModel->append());
   row[m_refTreeModel->m_Columns.m_col_id] = 1;
   row[m_refTreeModel->m_Columns.m_col_name] = "Billy Bob";
   row[m_refTreeModel->m_Columns.m_col_draggable] = true;
   row[m_refTreeModel->m_Columns.m_col_receivesdrags] = true;
 
-  Gtk::TreeModel::Row childrow = *(m_refTreeModel->append(row.children()));
+  auto childrow = *(m_refTreeModel->append(row.children()));
   childrow[m_refTreeModel->m_Columns.m_col_id] = 11;
   childrow[m_refTreeModel->m_Columns.m_col_name] = "Billy Bob Junior";
   childrow[m_refTreeModel->m_Columns.m_col_draggable] = true;
@@ -100,8 +100,6 @@ ExampleWindow::ExampleWindow()
           m_refTreeModel->m_Columns.m_col_draggable);
   m_TreeView.append_column_editable("Receives Drags",
           m_refTreeModel->m_Columns.m_col_receivesdrags);
-
-  show_all_children();
 }
 
 ExampleWindow::~ExampleWindow()
