@@ -14,16 +14,15 @@ win (TicTacToe *ttt)
 int
 main (int argc, char *argv[])
 {
-  auto app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
+  auto app = Gtk::Application::create("org.gtkmm.example");
 
   auto ttt = Gtk::make_managed<TicTacToe>();
   ttt->tictactoe.connect( sigc::bind (sigc::ptr_fun(&win), ttt) );
 
   Gtk::Window window;
   window.set_title("Tic-Tac-Toe");
-  window.set_border_width(10);
+  ttt->set_margin(10);
   window.add(*ttt);
-  window.show_all_children();
 
-  return app->run(window);
+  return app->run(window, argc, argv);
 }
