@@ -19,12 +19,12 @@
 #include <iostream>
 #include "exampletreemodel.h"
 
-ExampleTreeModel::GlueItem::GlueItem(int row_number)
+ExampleTreeModel::GlueItem::GlueItem(std::size_t row_number)
 : m_row_number(row_number)
 {
 }
 
-int ExampleTreeModel::GlueItem::get_row_number() const
+std::size_t ExampleTreeModel::GlueItem::get_row_number() const
 {
   return m_row_number;
 }
@@ -89,12 +89,12 @@ ExampleTreeModel::~ExampleTreeModel()
 //static:
 Glib::RefPtr<ExampleTreeModel> ExampleTreeModel::create()
 {
-  return Glib::RefPtr<ExampleTreeModel>( new ExampleTreeModel );
+  return Glib::make_refptr_for_instance( new ExampleTreeModel );
 }
 
-Gtk::TreeModelFlags ExampleTreeModel::get_flags_vfunc() const
+Gtk::TreeModel::Flags ExampleTreeModel::get_flags_vfunc() const
 {
-   return Gtk::TreeModelFlags(0);
+   return Gtk::TreeModel::Flags(0);
 }
 
 int ExampleTreeModel::get_n_columns_vfunc() const
@@ -110,7 +110,7 @@ GType ExampleTreeModel::get_column_type_vfunc(int index) const
     return 0;
 }
 
-void ExampleTreeModel::get_value_vfunc(const TreeModel::iterator& iter, int column, Glib::ValueBase& value) const
+void ExampleTreeModel::get_value_vfunc(const TreeModel::const_iterator& iter, int column, Glib::ValueBase& value) const
 {
   if(check_treeiter_validity(iter))
   {
@@ -124,10 +124,10 @@ void ExampleTreeModel::get_value_vfunc(const TreeModel::iterator& iter, int colu
       //Glib::Value< Glib::ustring > value_specific;
       //value_specific.init( Glib::Value< Glib::ustring >::value_type() ); //TODO: Is there any way to avoid this step?
 
-      typeListOfRows::const_iterator dataRowIter = get_data_row_iter_from_tree_row_iter(iter);
+      auto dataRowIter = get_data_row_iter_from_tree_row_iter(iter);
       if(dataRowIter != m_rows.end())
       {
-        const typeRow& dataRow = *dataRowIter;
+        const auto& dataRow = *dataRowIter;
 
         Glib::ustring result = dataRow[column];
 
@@ -149,7 +149,7 @@ bool ExampleTreeModel::iter_next_vfunc(const iterator& iter, iterator& iter_next
 
     //Get the current row:
     const auto pItem = (const GlueItem*)iter.gobj()->user_data;
-    typeListOfRows::size_type row_index = pItem->get_row_number();
+    auto row_index = pItem->get_row_number();
 
     //Make the iter_next GtkTreeIter represent the next row:
     row_index++;
@@ -175,12 +175,12 @@ bool ExampleTreeModel::iter_children_vfunc(const iterator& parent, iterator& ite
   return iter_nth_child_vfunc(parent, 0, iter);
 }
 
-bool ExampleTreeModel::iter_has_child_vfunc(const iterator& iter) const
+bool ExampleTreeModel::iter_has_child_vfunc(const const_iterator& iter) const
 {
   return (iter_n_children_vfunc(iter) > 0);
 }
 
-int ExampleTreeModel::iter_n_children_vfunc(const iterator& iter) const
+int ExampleTreeModel::iter_n_children_vfunc(const const_iterator& iter) const
 {
   if(!check_treeiter_validity(iter))
     return 0;
@@ -215,7 +215,7 @@ bool ExampleTreeModel::iter_nth_root_child_vfunc(int n, iterator& iter) const
     //Store the row_index in the GtkTreeIter:
     //See also iter_next_vfunc()
 
-    unsigned row_index = n;
+    const auto row_index = n;
 
     //This will be deleted in the GlueList destructor, when old iterators are marked as invalid.
     auto pItem = new GlueItem(row_index);
@@ -242,7 +242,7 @@ bool ExampleTreeModel::iter_parent_vfunc(const iterator& child, iterator& iter)
   return false; //There are no children, so no parents.
 }
 
-Gtk::TreeModel::Path ExampleTreeModel::get_path_vfunc(const iterator& /* iter */) const
+Gtk::TreeModel::Path ExampleTreeModel::get_path_vfunc(const const_iterator& /* iter */) const
 {
    //TODO:
    return Path();
@@ -272,7 +272,7 @@ bool ExampleTreeModel::get_iter_vfunc(const Path& path, iterator& iter) const
    //See also iter_next_vfunc()
    //TODO: Store a pointer to some more complex data type such as a typeListOfRows::iterator.
 
-   unsigned row_index = path[0];
+   const auto row_index = path[0];
    auto pItem = new GlueItem(row_index);
 
    //Store the GlueItem in the GtkTreeIter.
@@ -296,26 +296,26 @@ ExampleTreeModel::typeListOfRows::iterator ExampleTreeModel::get_data_row_iter_f
   //Don't call this on an invalid iter.
   const auto pItem = (const GlueItem*)iter.gobj()->user_data;
 
-  typeListOfRows::size_type row_index = pItem->get_row_number();
+  const auto row_index = pItem->get_row_number();
   if( row_index > m_rows.size() )
     return m_rows.end();
   else
     return m_rows.begin() + row_index; //TODO: Performance.
 }
 
-ExampleTreeModel::typeListOfRows::const_iterator ExampleTreeModel::get_data_row_iter_from_tree_row_iter(const iterator& iter) const
+ExampleTreeModel::typeListOfRows::const_iterator ExampleTreeModel::get_data_row_iter_from_tree_row_iter(const const_iterator& iter) const
 {
   //Don't call this on an invalid iter.
   const auto pItem = (const GlueItem*)iter.gobj()->user_data;
 
-  typeListOfRows::size_type row_index = pItem->get_row_number();
+  const auto row_index = pItem->get_row_number();
   if( row_index > m_rows.size() )
     return m_rows.end();
   else
     return m_rows.begin() + row_index; //TODO: Performance.
 }
 
-bool ExampleTreeModel::check_treeiter_validity(const iterator& iter) const
+bool ExampleTreeModel::check_treeiter_validity(const const_iterator& iter) const
 {
   // Anything that modifies the model's structure should change the model's stamp,
   // so that old iters are ignored.
